import { Request, Response } from "express";
import logger from "../logger/logger";
import Store from "../models/store";
import { getUserSession } from "../utils/utils";

// this request is needed to get the store id after the user has connected his calendar to redirect him back to the calendar page
export async function GetStoreId(req: Request, res: Response) {
  try {
    const userSession = await getUserSession(req);

    if (!userSession) {
      return res.status(401).send({ err: "unauthorized" });
    }

    // check if user has a store

    const store = await Store.findOne({
      where: {
        owner_user_id: userSession.user_id,
      },
      attributes: ["store_id"],
    });

    if (!store) {
      return res.status(401).send({ err: "unauthorized" });
    }

    res.status(200).send({ storeId: store.store_id });
  } catch (error) {
    logger.error(error);
    res.status(500).send({ err: "invalid request" });
  }
}

export async function GetCalendarSettings(req: Request, res: Response) {
  try {
    const userSession = await getUserSession(req);

    if (!userSession) {
      return res.status(401).send({ err: "unauthorized" });
    }

    // check if user has a store

    const store = await Store.findOne({
      where: {
        owner_user_id: userSession.user_id,
      },
      attributes: [
        "calendar_max_future_booking_days",
        "calendar_min_earliest_booking_time",
        "calendar_max_service_duration",
      ],
    });

    if (!store) {
      return res.status(401).send({ err: "unauthorized" });
    }

    console.log("test", req.user);

    res.status(200).send({
      settings: {
        calendar_max_future_booking_days:
          store.calendar_max_future_booking_days,
        calendar_min_earliest_booking_time:
          store.calendar_min_earliest_booking_time,
        calendar_max_service_duration: store.calendar_max_service_duration,
      },
    });
  } catch (error) {
    logger.error(error);
    res.status(500).send({ err: "invalid request" });
  }
}
